# GATE downloader

This directory contains a minimal setup to download all the dependencies
(JARs) for running GATE into the local Maven cache. 

The directory contains files

* `mvnw` and `mvnw.cmd` 
* directory `.mvn`

generated by:

* cloning https://github.com/takari/maven-wrapper
* running the command to build the wrapper 

In addition in contains a minimal pom.xml that contains the 
wanted GATE version as a dependency. 

In order to download the JARs, the following command 
gets run:

`./mvnw dependency:resolve`

which should download all the necessary JARs into the maven standard location for the system. 

## Alternatives

The (Scala-based) Coursier approach could also work: https://get-coursier.io/docs/api
